@@ -18,6 +18,9 @@ import sys
 import json
 import time
 
+
+
+
 #####################################################################
 
 from . import get_version
@@ -28,12 +31,13 @@ from . import s_log  , s_util
 config = { }
 config_alt = { }
 
-config_ready = False
+ready = False
 
 #####################################################################
 
 def setup( config_user = None ) :
-    global config_ready
+
+    global ready
 
     flag = init( config_user ) 
 
@@ -44,15 +48,45 @@ def setup( config_user = None ) :
     unpack_key( )
     checkup_workspacedir( )
 
-
-    config_ready = True
+    ready = True
 
     s_log.write( get_config( ) )
 
     return( True )
 
+def get_key( config_key , default_val = None ) :
+
+    #    config[ "/config/init/path" ] = config_path
+    #    config[ "/config/init/path_time" ] = os.path.getmtime( config_path )
+    # config[ "/config/cwd" ]
+    if( "/config/init/path_time" in config ) :
+        cd = config[ "/config/cwd" ]
+        cip = config[ "/config/init/path" ]
+        cipt = config[ "/config/init/path_time" ]
+
+        cfp = cd+"/"+cip
+
+    if( config_key in config_alt ) :
+        #s_log.write_msg("GET KEY FOUND")
+        if config_alt[ config_key ] != None :
+            return config_alt[ config_key ]
+ 
+
+    #s_log.write_msg("GET KEY "+config_key)
+    if( config_key in config ) :
+        #s_log.write_msg("GET KEY FOUND")
+        if config[ config_key ] != None :
+            return config[ config_key ]
+            
+    #s_log.write_msg("GET KEY NULL")
+    return default_val
+
+
+
 def checkup_workspacedir( ) :
+
     wd = get_key( "sys/workspacedir" )
+    
     if not wd :
         set_key( "sys/workspacedir" , "/tmp/sapiadapter" )
 
@@ -69,6 +103,8 @@ def unpack_key( ) :
 
     endpoint_url_token = endpoint_key
 
+    # FIXME TODO do not use ALT config
+    # FIXME TODO set blank or remove endpoint/host if not given
     if( len( parts ) == 2 ) :
         endpoint_url_token = parts[ 0 ]
         set_key_alt( "endpoint/host" , parts[ 1 ] )
@@ -81,11 +117,13 @@ def unpack_key( ) :
     set_key_alt( "endpoint/token" , token )
 
 
-def config_ready_get( ) :
-    return( config_ready )
+def isready( ) :
+    return( ready )
 
 
 def get_config( ) :
+    # FIXME TODO merge alt config... otherwise you dont have full picture
+    # FIXME TODO have log that outputs both config and alt!
     return config
 
 def set_key( config_key , config_val ) :
@@ -111,23 +149,6 @@ def del_key_alt( kn ) :
     #s_log.write_msg("GET KEY NULL")
     return False
 
-def get_key( config_key , default_val = None ) :
-
-    if( config_key in config_alt ) :
-        #s_log.write_msg("GET KEY FOUND")
-        if config_alt[ config_key ] != None :
-            return config_alt[ config_key ]
- 
-
-    #s_log.write_msg("GET KEY "+config_key)
-    if( config_key in config ) :
-        #s_log.write_msg("GET KEY FOUND")
-        if config[ config_key ] != None :
-            return config[ config_key ]
-            
-    #s_log.write_msg("GET KEY NULL")
-    return default_val
-
 def key_is_yes( kn ) :
     v = get_key( kn )
     if(v=="yes"): return(True)
@@ -135,8 +156,8 @@ def key_is_yes( kn ) :
 
 def key_is_no( kn ) :
     v = get_key( kn )
-    if(v=="no"): return(True)
-    return(False)
+    if( v == "no" ) : return( True )
+    return( False )
 
 def del_key( kn ) :
     #s_log.write_msg("GET KEY "+config_key)
@@ -148,6 +169,8 @@ def del_key( kn ) :
     #s_log.write_msg("GET KEY NULL")
     return False
 
+################################################################
+
 def init_fromfile( config_path , config_key = "sapiadapter" ) :
 
     global config
@@ -168,20 +191,39 @@ def init_fromfile( config_path , config_key = "sapiadapter" ) :
 
     if config_key in config_all :
         config.update( config_all[ config_key ] )
-        config["config/init_fromfile" ] = "yes"
-        config["config/init_fromfile_path"] = config_path
+        #config["config/init_fromfile" ] = "yes"
+        config[ "/config/init/path" ] = config_path
+        config[ "/config/init/path_time" ] = os.path.getmtime( config_path )
     else :
         s_log.write( "ERROR config_key " + config_key )
         return False
 
     ####################################################################
 
-    #s_log.write( "LOADED " + config_path )
-
-    #s_log.write( config )
+    # s_log.write( "LOADED " + config_path )
+    # s_log.write( config )
 
     return True
 
+def load_from_file( cp ) :
+    if not os.path.isabs(cp):
+        s_log.write( "load_from_file file path not absolute" )
+        return( False )
+    if not os.path.isfile( cp ) :
+        s_log.write( "load_from_file file not found" )
+        return( False )
+
+    if not init_fromfile( cp ) :
+        s_log.write( "load_from_file init_fromfile false" )
+        return( False )
+
+    unpack_key( )   
+    config[ "/config/init/from" ] = "manual_file"
+    s_log.write( "CONFIG MANUAL" ) 
+    s_log.write( config ) 
+    return( True )
+
+
 ################################################################
 
 def init( config_user = None ) :
@@ -192,18 +234,22 @@ def init( config_user = None ) :
 
     # Use "/..." for internal config keys...
 
-    config[ "/config/init/time" ] = time.time( )
+    t1 = time.time( )
+    config[ "/config/init/time" ] = t1
+    config[ "/config/init/time_lap" ] = t1
     config[ "/config/version" ] = get_version( )
     config[ "/config/cwd" ] = os.getcwd( )
-    config[ "/config/scriptdir" ] = os.path.dirname( os.path.realpath( __file__ ) )
-    config[ "/config/maindir" ] = os.path.dirname( sys.modules[ "__main__" ].__file__ )
+    #config[ "/config/scriptdir" ] = os.path.dirname( os.path.realpath( __file__ ) )
     config[ "/config/session" ] = s_util.uhash( )
 
+
+    config[ "/config/parentpath" ] = s_util.parent_path()
+
     #s_log.write( config )
 
     if( config_user ) :
         config.update( config_user )
-        config[ "/config/init/user" ] = "yes"
+        config[ "/config/init/from" ] = "config_user"
         return( True ) 
 
     ################################################################
@@ -213,7 +259,7 @@ def init( config_user = None ) :
         #s_log.write( "Found env var SAPIADAPTER_CONFIGURATION" )
         if( init_fromfile( os.environ[ "SAPIADAPTER_CONFIGURATION" ] ) ) :
             s_log.write( "Loaded SAPIADAPTER_CONFIGURATION " + os.environ[ "SAPIADAPTER_CONFIGURATION" ] )
-            config[ "/config/init/init_fromfile" ] = "environ"
+            config[ "/config/init/from" ] = "environ_file"
             return( True )
         else :
             return( False )
@@ -229,7 +275,7 @@ def init( config_user = None ) :
     if os.path.isfile( config_default_filename ) :
         if( init_fromfile( config_default_filename ) ) :
             s_log.write( "Loaded " + config_default_filename )
-            config[ "/config/init/init_fromfile" ] = "cwd"
+            config[ "/config/init/from" ] = "cwd_file"
             return( True )
         return( False )
 
@@ -242,20 +288,25 @@ def init( config_user = None ) :
     if os.path.isfile( testpath + config_default_filename ) :
         if( init_fromfile( testpath + config_default_filename ) ) :
             s_log.write( "Loaded " + testpath + config_default_filename )
-            config[ "/config/init/init_fromfile" ] = "tests"
+            config[ "/config/init/from" ] = "testsdata_file"
             return( True )
         return( False )
 
     ################################################################
 
+    #try:
+    #    config[ "/config/maindir" ] = os.path.dirname( sys.modules[ "__main__" ].__file__ )
+    #except:
+    #    s_log.write("maindir main/file EXCEPTION")
+
     # Lets check 'main' directory for config file
-    testpath = config[ "/config/maindir" ] +"/" + config_default_filename
-    if os.path.isfile( testpath ) :
-        if( init_fromfile( testpath ) ) :
-            s_log.write( "Loaded " + testpath )
-            config[ "/config/init/init_fromfile" ] = "main"
-            return( True )
-        return( False )
+    #testpath = config[ "/config/maindir" ] + "/" + config_default_filename
+    #if os.path.isfile( testpath ) :
+    #    if( init_fromfile( testpath ) ) :
+    #        s_log.write( "Loaded " + testpath )
+    #        config[ "/config/init/from" ] = "maindir_file"
+    #        return( True )
+    #    return( False )
 
     #s_log.write( "Not found " + os.getcwd( ) + "/" + testpath + config_default_filename )
 
