@@ -178,7 +178,7 @@ def db_dirty_get( ) :
 #####################################################################
 
 def sql_execute( sql ) :
-    #s_log.write(sql)
+    s_log.write( sql )
     cur = db_con.cursor( )
     cur.execute( sql )
     db_con.commit( )
