@@ -81,7 +81,7 @@ def check_connectivity( ) :
 
     ################################################################
 
-    if( flag_networkok and get_request_response( ) == False ) :
+    if( flag_networkok and get_request_response( {"X-Omni-Action": "mwget"}) == False ) :
         s_log.write( "False check_connectivity 2" )
         flag_networkok = False
 
@@ -95,7 +95,7 @@ def check_connectivity( ) :
     endpoint_host =  s_config.get_key( "endpoint/host" , "HOST_NOT_SET")
     s_log.write( endpoint_parseurl.hostname + "," + str( endpoint_url_port ) + "," + endpoint_host )
 
-    if( ( endpoint_url_port != 443 ) or ( endpoint_url_port != 10443 ) ) :
+    if( ( endpoint_url_port != 443 ) and ( endpoint_url_port != 10443 ) ) :
         s_log.write( "maybe endpoint_url_port smells fishy..." )
 
     return( False )
@@ -197,6 +197,11 @@ def job_response( jid ) :
         s_log.write( "job_response !=Done [" + jid + "]" )
         return( None )
 
+    if(len(res.content)==0):
+        s_log.write( "ERROR EMPTY RES CONTENT" )
+        return( False )
+
+
     s_db.blob_set( res.content )
 
     return( True )
