@@ -23,6 +23,7 @@ import hashlib
 import base64
 import shutil
 import gzip
+import inspect
 
 from subprocess import Popen, PIPE
 
@@ -111,12 +112,26 @@ def is_ip( address ) :
 def uptime( ) :
     return( time.time( ) - s_config.get_key( "/config/init/time" ) )
 
+
+def uptime_lap( ) :
+
+    tn = time.time( )
+
+    tlp = s_config.get_key( "/config/init/time_lap" )  
+
+    tl = tn - tlp 
+
+    s_config.set_key( "/config/init/time_lap" , tn )
+
+    return( tl )
+
+
 def printexit( msg ) :
     print( msg )
     sys.exit( )
 
 
-def printexception( e=False ) :
+def printexception( e = False ) :
     if e:
         print( "EXCEPTION" + str( e ) )
     etype , value, tb = sys.exc_info( )
@@ -134,7 +149,26 @@ def heartbeat( t = 60 ) :
     return( True )
 
 def ready( ) :
-    if( not s_config.config_ready_get( ) ) :
+
+    config = s_config.get_config( )
+    if "/config/init/path_time" in config :
+        cd = config[ "/config/cwd" ]
+        cip = config[ "/config/init/path" ]
+        cipt = config[ "/config/init/path_time" ]
+
+        cfp=cip
+        if not os.path.isabs(cip):
+            cfp = cd + "/" + cip
+        cipt2 = os.path.getmtime( cfp )
+        if( os.path.getmtime( cfp ) != cipt ) :
+            s_config.setup( )
+            s_db.setup( )
+            s_log.write( "RELOADED " )
+            #s_log.write( "CONFIG RELOADED " + cfp + str( cipt ) )
+
+    ####################################################################
+
+    if( not s_config.isready( ) ) :
         return( False )
 
     if( not s_net.check_connectivity( ) ) :
@@ -247,3 +281,41 @@ def compress( d ) :
 def decompress( d ) :
     blob = gzip.decompress( d )
     return( blob )
+
+
+def parent_path( ) :
+
+    for teil in inspect.stack():
+        # skip system calls
+        if teil[1].startswith("<"):
+            continue
+        if teil[1].upper().startswith(sys.exec_prefix.upper()):
+            continue
+        trc = teil[1]
+        
+    # trc contains highest level calling script name
+    # check if we have been compiled
+    if getattr(sys, 'frozen', False):
+        scriptdir, scriptname = os.path.split(sys.executable)
+        return {"dir": scriptdir,
+                "name": scriptname,
+                "source": trc}
+
+    # from here on, we are in the interpreted case
+    scriptdir, trc = os.path.split(trc)
+    # if trc did not contain directory information,
+    # the current working directory is what we need
+    if not scriptdir:
+        scriptdir = os.getcwd()
+
+    scr_dict ={"name": trc,
+               "source": trc,
+               "dir": scriptdir}
+
+    #s_log.write(scr_dict)
+
+    return scr_dict["dir"]
+    
+
+
+
