@@ -28,6 +28,21 @@ s_db.setup( )
 
 #####################################################################
 
+
+def test( ) :
+
+    if( not s_util.ready( ) ) :
+        s_log.write( "ERROR False ready" )
+        return( False )
+
+    s_log.write( "OK" )
+    return( True )
+
+#####################################################################
+
+def config_load_from_file( cp ) :
+    return( s_config.load_from_file( cp ) )
+
 def ready( ) :
     return( s_util.ready( ) )
 
@@ -42,6 +57,8 @@ def defmeta( ) :
 
 def uptime( ) :
     return( s_util.uptime( ) )
+def uptime_lap( ) :
+    return( s_util.uptime_lap( ) )
 
 def heartbeat( t = 60 ) :
     return( s_util.heartbeat( t ) )
@@ -68,7 +85,7 @@ def server( ) :
         
         if flag_jobget == False :
 
-            print( "ERROR False job_get" )
+            s_log.write( "ERROR False job_get" )
             continue
             #sapi.prexit( "False job_get" )
 
@@ -89,7 +106,7 @@ def server( ) :
             s_db.files_defdata_set( defdata )
             s_db.files_defmeta_set( defmeta)
             s_net.job_set( )
-            print( "OK PINGPONG" )
+            s_log.write( "OK PINGPONG" )
             continue
 
         #####################################################
@@ -111,7 +128,7 @@ def server( ) :
 
         #####################################################
 
-        print( "OK" )
+        s_log.write( "OK" )
 
 
 
@@ -120,15 +137,17 @@ def server( ) :
 
 # DATA
 # TIMEOUT
-def express( meta_inputs = { } , wait_timeout = 60 ) :
+def run( meta_inputs = { } , wait_timeout = 60 ) :
 
     if( not ready( ) ) :
         s_log.write( "NOT READY" )
         return( False )
 
     if( not meta_inputs ) :
-        s_log.write( "false meta_inputs " )
-        return( False )
+        #s_log.write( "false meta_inputs " )
+        #return( False )
+        meta_inputs["module"] = "sparc1/test_read_metadata_odi/entrypoint1"
+
 
     if( not isinstance( meta_inputs , ( dict ) ) ) :
         s_log.write( "false meta_inputs dict" )
@@ -180,4 +199,5 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    return( True )
+    #return( True )
+    return( defdata( ) )
